Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3993)

Unified Diff: chrome/test/ispy/client/boto_bucket.py

Issue 1418513007: Move find_depot_tools.py to build/ (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: review fixes Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/web_dev_style/resource_checker_test.py ('k') | mojo/services/upload_service.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/ispy/client/boto_bucket.py
diff --git a/chrome/test/ispy/client/boto_bucket.py b/chrome/test/ispy/client/boto_bucket.py
index 139d83c4df857d4b588d62b9f76aa57fb24c7142..ce963bc3d6b2ea32020e6ed7bf5df82aeb3de066 100644
--- a/chrome/test/ispy/client/boto_bucket.py
+++ b/chrome/test/ispy/client/boto_bucket.py
@@ -7,9 +7,9 @@ import os
import sys
# boto requires depot_tools/third_party be in the path. Use
# src/tools/find_depot_tools.py to add this directory.
sys.path.append(os.path.join(os.path.dirname(__file__), os.pardir, os.pardir,
- os.pardir, os.pardir, 'tools'))
+ os.pardir, os.pardir, 'build'))
import find_depot_tools
DEPOT_TOOLS_PATH = find_depot_tools.add_depot_tools_to_path()
sys.path.append(os.path.join(os.path.abspath(DEPOT_TOOLS_PATH), 'third_party'))
@@ -45,7 +45,7 @@ class BotoCloudBucket(cloud_bucket.BaseCloudBucket):
key.set_contents_from_string(contents)
# Open permissions for the appengine account to read/write.
key.add_email_grant('FULL_CONTROL',
- 'ispy.google.com@appspot.gserviceaccount.com')
+ 'ispy.google.com@appspot.gserviceaccount.com')
# override
def DownloadFile(self, path):
« no previous file with comments | « chrome/browser/web_dev_style/resource_checker_test.py ('k') | mojo/services/upload_service.py » ('j') | no next file with comments »
@@ -7,9 +7,9 @@ import os
import sys
# boto requires depot_tools/third_party be in the path. Use
-# src/tools/find_depot_tools.py to add this directory.
+# src/build/find_depot_tools.py to add this directory.
sys.path.append(os.path.join(os.path.dirname(__file__), os.pardir, os.pardir,

Powered by Google App Engine
This is Rietveld 408576698